@@ -30,15 +30,15 @@
 #include "progressbar.h"
 #include "systemconfig.h"
 
-#include <ntqdatetimeedit.h>
-#include <ntqfile.h>
-#include <ntqhbox.h>
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqtimer.h>
-#include <ntqtooltip.h>
-#include <ntqvgroupbox.h>
-#include <ntqwhatsthis.h>
+#include <tqdatetimeedit.h>
+#include <tqfile.h>
+#include <tqhbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqtimer.h>
+#include <tqtooltip.h>
+#include <tqvgroupbox.h>
+#include <tqwhatsthis.h>
 
 #include <dcopclient.h>
 #include <tdeaction.h>
@@ -952,3 +952,4 @@ bool MMainWindow::queryExit()
 
 	return true; // ok to exit
 }
+#include "mmainwindow.moc"
